* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Meta Model Extensions](https://help.sap.com/docs/leanix/ea/meta-model-extensions)
  * SAP Suggestions in Your Landscape Extension to the …
